#
# spec file for package sysfsutils
#
# Copyright (c) 2020 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sysfsutils
Summary:        System Utilities Package / Libsysfs
License:        LGPL-2.1+
Group:          System/Libraries
Version:        2.1.0
Release:        lp151.3.3.1
URL:            https://github.com/linux-ras/sysfsutils
Source:         https://aleron.dl.sourceforge.net/sourceforge/linux-diag/%{name}-%{version}.tar.gz
Source2:        baselibs.conf
Patch1:         %{name}-Fix-issue-with-sysfs-name-comparisons.patch
Patch2:         %{name}-Limit-cdev-name-length-comparsion-to-strlen-1.patch
Provides:       libsysfs
# bug437293
%ifarch ppc64
Obsoletes:      sysfsutils-64bit
%endif
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package's purpose is to provide a library for interfacing with the
kernel's sys filesystem mounted at /sys. The library was an attempt to
create a stable interface to sysfs, but it failed. It is still provided
for the current users, but no new software should use this library.



Authors:
--------
    Ananth Mavinakayanahalli <ananth@in.ibm.com>
    Daniel Stekloff <dsteklof@us.ibm.com>
    Mohan Kumar <mohan@in.ibm.com>

%package devel
Summary:        Development files for libsysfs
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Libsysfs' purpose is to provide a library for interfacing with the
kernel's sys filesystem mounted at /sys. The library was an attempt to
create a stable interface to sysfs, but it failed. It is still provided
for the current users, but no new software should use this library.

This package contains the development files for libsysfs.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

%build
%configure --disable-static --with-pic
%{__make} %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}
%{__rm} -v %{buildroot}/%{_libdir}/libsysfs.la
# don't install the tools
rm -f %{buildroot}/%{_bindir}/dlist_test
rm -f %{buildroot}/%{_bindir}/get_device
rm -f %{buildroot}/%{_bindir}/get_driver
rm -f %{buildroot}/%{_bindir}/get_module
rm -f %{buildroot}/%{_bindir}/testlibsysfs

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
/usr/bin/systool
%{_mandir}/man1/systool.1.gz
%{_libdir}/libsysfs.so.*
%doc README ChangeLog

%files devel
%defattr(-,root,root)
%dir %{_includedir}/sysfs
%{_includedir}/sysfs/libsysfs.h
%{_includedir}/sysfs/dlist.h
%{_libdir}/libsysfs.so

%changelog
* Fri Jul 10 2020 Lee Duncan <lduncan@suse.com>
- Fix cdev name comparison (bsc#1155305), adding patches:
  * sysfsutils-Fix-issue-with-sysfs-name-comparisons.patch
  * sysfsutils-Limit-cdev-name-length-comparsion-to-strlen-1.patch
* Thu Feb 16 2012 crrodriguez@opensuse.org
- Libraries are back to %%{_libdir}, /usr merge project
* Tue Sep  7 2010 aj@suse.de
- Create devel package.
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Sat Dec 19 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Mar 24 2009 crrodriguez@suse.de
- remove static libraries
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue May 27 2008 hare@suse.de
- Include systool binary (bnc#391754)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Jan 16 2007 hare@suse.de
- Run ldconfig on %%post (#204063)
- Do not duplicate .so symlink (#235332)
* Thu Aug 31 2006 kay.sievers@suse.de
- update to version 2.1.0
- provide only the shared lib, not the static lib, not the tools
* Thu Mar  9 2006 hare@suse.de
- Do not install testlibsysfs (#149981 - LTC21580)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 hmacht@suse.de
- also substitude libtool path in *.la file when moving libraries
  (bug #141161)
* Fri Jun 24 2005 snwint@suse.de
- move shared libs to /lib
* Fri Jun 10 2005 hare@suse.de
- initial release 1.3.0; split off from udev rpm.
